@@ -157,6 +157,8 @@ TRAITS = [
     "regent",
     "priscus",
     "baron",
+    "anarch",
+    "laibon",
     "liaison",
     "magaji",
     "kholo",
@@ -454,20 +456,16 @@ TYPE_ORDER = [
     "Action",
     "Action/Combat",
     "Action/Reaction",
-    "Political Action",
-    "Action Modifier",
-    "Action Modifier/Reaction",
-    "Action Modifier/Combat",
-    "Combat",
-    "Combat/Action",
-    "Combat/Action Modifier",
-    "Combat/Reaction",
-    "Reaction",
-    "Reaction/Action Modifier",
-    "Reaction/Combat",
-    "Power",
-    "Equipment",
     "Ally",
+    "Equipment",
+    "Political Action",
     "Retainer",
+    "Power",
+    "Action Modifier",
+    "Action Modifier/Combat",
+    "Action Modifier/Reaction",
+    "Reaction",
+    "Combat",
+    "Combat/Reaction",
     "Event",
 ]
